==> haskell-hslua-packaging-2.3.1-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-packaging.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-packaging
version:              2.3.1
visibility:           public
id:                   hslua-packaging-2.3.1-FTZcqYAUUAXLQGWOOaaXmd
key:                  hslua-packaging-2.3.1-FTZcqYAUUAXLQGWOOaaXmd
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Utilities to build Lua modules.
description:
    Utilities to package up Haskell functions and
    values into a Lua module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  ffffc98cda9a8b1118ea1654d6034c69
exposed:              True
exposed-modules:
    HsLua.Packaging HsLua.Packaging.Convenience
    HsLua.Packaging.Documentation HsLua.Packaging.Function
    HsLua.Packaging.Module HsLua.Packaging.Rendering
    HsLua.Packaging.Types HsLua.Packaging.UDType

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-packaging-2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-packaging-2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-packaging-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-packaging
hs-libraries:         HShslua-packaging-2.3.1-FTZcqYAUUAXLQGWOOaaXmd
depends:
    base-4.17.2.1 containers-0.6.7
    hslua-core-2.3.1-8UKtW8ALUvCDY9LUMLjR8F
    hslua-marshalling-2.3.1-7B3Sre5ByLi7setfeS2P6E
    hslua-objectorientation-2.3.0-4EUSteFzhyCAFP9bdqXr8c
    hslua-typing-0.1.1-3cilkW91NRF70LNZBHei1a mtl-2.2.2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-packaging/html/hslua-packaging.haddock

haddock-html:         /usr/share/doc/haskell-hslua-packaging/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-packaging-2.3.1-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-packaging.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-packaging
version:              2.3.1
visibility:           public
id:                   hslua-packaging-2.3.1-K5yVHDAHi3j8CiA9XeLwva
key:                  hslua-packaging-2.3.1-K5yVHDAHi3j8CiA9XeLwva
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Utilities to build Lua modules.
description:
    Utilities to package up Haskell functions and
    values into a Lua module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  d74b559583f10e664f8fc87caf47d513
exposed:              True
exposed-modules:
    HsLua.Packaging HsLua.Packaging.Convenience
    HsLua.Packaging.Documentation HsLua.Packaging.Function
    HsLua.Packaging.Module HsLua.Packaging.Rendering
    HsLua.Packaging.Types HsLua.Packaging.UDType

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-packaging-2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-packaging-2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-packaging-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-packaging
hs-libraries:         HShslua-packaging-2.3.1-K5yVHDAHi3j8CiA9XeLwva
depends:
    base-4.17.2.1 containers-0.6.7
    hslua-core-2.3.1-54rXN7zYylbDApFlVoB5xw
    hslua-marshalling-2.3.1-FncQmvmsHr0H9hRnpxXZJ0
    hslua-objectorientation-2.3.0-JfWg42S5GB48ESo2qUvvxX
    hslua-typing-0.1.1-1ThvzeLiEyU2Dm0VZg6ugA mtl-2.2.2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-packaging/html/hslua-packaging.haddock

haddock-html:         /usr/share/doc/haskell-hslua-packaging/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
